import kotlinx.serialization.ExperimentalSerializationApi
import kotlinx.serialization.encodeToString
import kotlinx.serialization.json.Json
import kotlinx.serialization.json.decodeFromStream
import model.Card
import model.GameCh
import java.io.File

@ExperimentalSerializationApi
fun main(args: Array<String>) {
    val cardList = readJson<List<Card>>(fileName = "card.json")
    cardList.forEach { card ->
        card.illustId = "c_${card.illustId}.png"
        card.evolveIllustId = "c_${card.evolveIllustId}.png"
    }

    val gameList = readJson<List<GameCh>>(fileName = "gamerch.json")

    cardList.forEach { card ->
        gameList.find { gameCh -> gameCh.name.contains(card.name) }?.let { gameCh ->
            card.url = gameCh.url
        }
    }

    val encodeJson = Json { prettyPrint = true }
    val prettyJson = encodeJson.encodeToString(cardList)
//    println(prettyJson)

    val outputFile = File("src/main/resources/card_fix.json")
    outputFile.writeText(prettyJson)
}

@OptIn(ExperimentalSerializationApi::class)
inline fun <reified T> readJson(fileName: String): T {
    val fis = object {}.javaClass.getResourceAsStream(fileName)!!
    val decodeJson = Json { ignoreUnknownKeys = true }
    return decodeJson.decodeFromStream<T>(fis)
}